  WSGIappLocaleSet()->setLocaleString("EUCCN","","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","A3:WSSTR Can not create class: %s.\nPlease check the import library is right."," %s  \nȷ׷ӵǷȷ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","B3:WSSTR The name %s is already used by another instance.","%s ظ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","C3:WSSTR Normal:0:,Invisible:4:,Deleted:1:,Default changed:2:,Hidden:3:","ͨ:0:,ɼ:4:,ɾ:1:,޸Ĭֵ:2:,:3:");
  WSGIappLocaleSet()->setLocaleString("EUCCN","D3:WSSTR Target class:","Ŀ:");
  WSGIappLocaleSet()->setLocaleString("EUCCN","E3:WSSTR Property name:",":");
  WSGIappLocaleSet()->setLocaleString("EUCCN","F3:WSSTR Property type:",":");
  WSGIappLocaleSet()->setLocaleString("EUCCN","G3:WSSTR Variable name:",":");
  WSGIappLocaleSet()->setLocaleString("EUCCN","H3:WSSTR Default value:","Ĭֵ:");
  WSGIappLocaleSet()->setLocaleString("EUCCN","I3:WSSTR Attribute:",":");
  WSGIappLocaleSet()->setLocaleString("EUCCN","J3:WSSTR Builder title:",":");
  WSGIappLocaleSet()->setLocaleString("EUCCN","K3:WSSTR Select menu:","ѡ˵:");
  WSGIappLocaleSet()->setLocaleString("EUCCN","L3:WSSTR Warning","ע");
  WSGIappLocaleSet()->setLocaleString("EUCCN","M3:WSSTR Invalid property name.\nPlease specify another name like WSNxxxx...","Ƿ\nָ WSN ͷȷ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","N3:WSSTR Invalid variable name...","ָȷı");
  WSGIappLocaleSet()->setLocaleString("EUCCN","O3:WSSTR This name is already used by another procedure...","ָѱ̺ʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","P3:WSSTR This name is already used by another external instance.","ָѱⲿʵʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","Q3:WSSTR This name is already used by another external instance array.","ָѱⲿʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","R3:WSSTR This property name is already used by another property.","ظָ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","S3:WSSTR The variable is already used.","ѱʹãָͬı");
  WSGIappLocaleSet()->setLocaleString("EUCCN","T3:WSSTR Create","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","U3:WSSTR Please specify the target class window.","ָĿരڡ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","V3:WSSTR Please select the property.","ѡԡ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","W3:WSSTR Question","ȷ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","X3:WSSTR Is it OK to delete the property?","ȷɾԣ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","Y3:WSSTR Update","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","Z3:WSSTR Create new property","½");
  WSGIappLocaleSet()->setLocaleString("EUCCN","a3:WSSTR Edit property","༭");
  WSGIappLocaleSet()->setLocaleString("EUCCN","b3:WSSTR Delete property","ɾ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","c3:WSSTR Type,Property name,Member name,Attribute,Default value",",,Ա,,Ĭֵ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","d3:WSSTR New:NEW:,Edit:EDIT:,Delete:DEL:","½:NEW:,༭:EDIT:,ɾ:DEL:");
  WSGIappLocaleSet()->setLocaleString("EUCCN","e3:WSSTR  Use the handler defined by user","ʹûľ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","f3:WSSTR (Normal)","(ͨ)");
  WSGIappLocaleSet()->setLocaleString("EUCCN","g3:WSSTR (Deleted)","(ɾ)");
  WSGIappLocaleSet()->setLocaleString("EUCCN","h3:WSSTR (DefaultChanged)","(޸Ĭֵ)");
  WSGIappLocaleSet()->setLocaleString("EUCCN","i3:WSSTR (Hidden)","()");
  WSGIappLocaleSet()->setLocaleString("EUCCN","j3:WSSTR (Invisible)","(ɼ)");
  WSGIappLocaleSet()->setLocaleString("EUCCN","k3:WSSTR Normal Def.:0:,Delete Def.:1:","ͨ:0:,ɾ:1:");
  WSGIappLocaleSet()->setLocaleString("EUCCN","l3:WSSTR Target class:","עĿ:");
  WSGIappLocaleSet()->setLocaleString("EUCCN","m3:WSSTR Trigger name:",":");
  WSGIappLocaleSet()->setLocaleString("EUCCN","n3:WSSTR Define name:","ַ:");
  WSGIappLocaleSet()->setLocaleString("EUCCN","o3:WSSTR Define value:","ֵ:");
  WSGIappLocaleSet()->setLocaleString("EUCCN","p3:WSSTR Define type:","Ͷ:");
  WSGIappLocaleSet()->setLocaleString("EUCCN","q3:WSSTR Invalid trigger name.","ָϷĴ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","r3:WSSTR Invalid define string...","ָϷĶַ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","s3:WSSTR Please specify the define value > 31.","ָ 32 ֵ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","t3:WSSTR This trigger name is already used by another one.","ظ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","u3:WSSTR The define string is already used.","ַظ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","v3:WSSTR The value is already used.","ֵָظ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","w3:WSSTR Please select the trigger.","ѡ񴥷");
  WSGIappLocaleSet()->setLocaleString("EUCCN","x3:WSSTR Is it OK to delete the trigger?","ȷɾ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","y3:WSSTR Create new trigger","½");
  WSGIappLocaleSet()->setLocaleString("EUCCN","z3:WSSTR Edit trigger","༭");
  WSGIappLocaleSet()->setLocaleString("EUCCN","A3:WSSTR Delete trigger","ɾ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","B3:WSSTR Trigger Name,Trigger def,Trigger value,Attribute",",ַ,ֵ,Զ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","C3:WSSTR New:NEW:,Edit:EDIT:,Delete:DEL:","½:NEW:,༭:EDIT:,ɾ:DEL:");
  WSGIappLocaleSet()->setLocaleString("EUCCN","D3:WSSTR All:","ȫ:");
  WSGIappLocaleSet()->setLocaleString("EUCCN","E3:WSSTR R:",":");
  WSGIappLocaleSet()->setLocaleString("EUCCN","F3:WSSTR G:",":");
  WSGIappLocaleSet()->setLocaleString("EUCCN","G3:WSSTR B:",":");
  WSGIappLocaleSet()->setLocaleString("EUCCN","H3:WSSTR Color:","ɫ:");
  WSGIappLocaleSet()->setLocaleString("EUCCN","I3:WSSTR Name:",":");
  WSGIappLocaleSet()->setLocaleString("EUCCN","J3:WSSTR Add user color","ûԶɫ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","K3:WSSTR Edit user color","༭ûԶɫ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","L3:WSSTR Delete user color","ɾûԶɫ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","M3:WSSTR Default colors,Standard colors,User defined colors","Ĭɫ,׼ɫ,ûԶɫ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","N3:WSSTR Please select the user color.","ѡûԶɫ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","O3:WSSTR Delete the selected color: ","ѡɫ: ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","P3:WSSTR  ?"," ɾ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","Q3:WSSTR Please select the user color to delete.","ѡɾûԶɫ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","R3:WSSTR %s:DISP:,Save:SAVE:,Search:SEARCH:,SP,Compile:COMP:,%s:PRJ:,SP,Copy:COPY:,Paste:PASTE:,SP,Delete:DEL:","%s:DISP:,:SAVE:,:SEARCH:,SP,:COMP:,%s:PRJ:,SP,:COPY:,ճ:PASTE:,SP,ɾ:DEL:");
  WSGIappLocaleSet()->setLocaleString("EUCCN","S3:WSSTR Files,Instances,Properties,Procedures,Attributes","ļ,ʵ,,,");
  WSGIappLocaleSet()->setLocaleString("EUCCN","T3:WSSTR Name,Class",",");
  WSGIappLocaleSet()->setLocaleString("EUCCN","U3:WSSTR None:NONE:",":NONE:");
  WSGIappLocaleSet()->setLocaleString("EUCCN","V3:WSSTR Display","ʾ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","W3:WSSTR Add to project","ڹע");
  WSGIappLocaleSet()->setLocaleString("EUCCN","X3:WSSTR Dismiss","ɾ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","Y3:WSSTR Remove from project","ӹɾ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","Z3:WSSTR Add procedure","ӹ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","a3:WSSTR Properties","ù");
  WSGIappLocaleSet()->setLocaleString("EUCCN","b3:WSSTR Edit procedure","༭");
  WSGIappLocaleSet()->setLocaleString("EUCCN","c3:WSSTR Delete procedure","ɾ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","d3:WSSTR Instance:","עĿ:");
  WSGIappLocaleSet()->setLocaleString("EUCCN","e3:WSSTR Procedure name:",":");
  WSGIappLocaleSet()->setLocaleString("EUCCN","f3:WSSTR Trigger:",":");
  WSGIappLocaleSet()->setLocaleString("EUCCN","g3:WSSTR Function name:",":");
  WSGIappLocaleSet()->setLocaleString("EUCCN","h3:WSSTR Invalid procedure name...","ָȷĹơ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","i3:WSSTR Invalid function name...","ָȷĺơ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","j3:WSSTR Invalid procedure name...","ָȷĹơ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","k3:WSSTR Invalid procedure name.\nAlready used by another procedure name.","ָѱ̺ʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","l3:WSSTR Invalid procedure name.\nAlready used by another instance name.","ָѱⲿʵʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","m3:WSSTR Invalid procedure name.\nAlready used by another instance array name.","ָѱⲿʵʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","n3:WSSTR Invalid function name.","ָӢĸֵĺơ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","o3:WSSTR Create %s.cpp...","%s.cpp");
  WSGIappLocaleSet()->setLocaleString("EUCCN","p3:WSSTR Create %s/%s.cpp...","%s/%s.cpp");
  WSGIappLocaleSet()->setLocaleString("EUCCN","o3:WSSTR Create %s.rb...","%s.rb");
  WSGIappLocaleSet()->setLocaleString("EUCCN","p3:WSSTR Create %s/%s.rb...","%s/%s.rb");
  WSGIappLocaleSet()->setLocaleString("EUCCN","o3:WSSTR Create %s.py...","%s.py");
  WSGIappLocaleSet()->setLocaleString("EUCCN","p3:WSSTR Create %s/%s.py...","%s/%s.py");
  WSGIappLocaleSet()->setLocaleString("EUCCN","o3:WSSTR Create %s.pl...","%s.pl");
  WSGIappLocaleSet()->setLocaleString("EUCCN","p3:WSSTR Create %s/%s.pl...","%s/%s.pl");
  WSGIappLocaleSet()->setLocaleString("EUCCN","q3:WSSTR Overwrite existing file: %s?","ȷϸ %s ļ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","r3:WSSTR OK","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","s3:WSSTR Please specify a target instance.","ָĿ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","t3:WSSTR Please select a procedure.","ѡ̡");
  WSGIappLocaleSet()->setLocaleString("EUCCN","u3:WSSTR The procedure does not exist.","ָĹ̲ڡ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","v3:WSSTR Delete this procedure?","ȷɾ̣");
  WSGIappLocaleSet()->setLocaleString("EUCCN","w3:WSSTR Procedure name,Trigger,Function name",",,");
  WSGIappLocaleSet()->setLocaleString("EUCCN","x3:WSSTR File...","ѡļ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","y3:WSSTR Template","ģ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","z3:WSSTR Internal","ڲ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","A3:WSSTR New:NEW:,Properties:SET:,Edit procedure:EDIT:,Delete procedure:DEL:","½:NEW:,ù:SET:,༭:EDIT:,ɾ:DEL:");
  WSGIappLocaleSet()->setLocaleString("EUCCN","B3:WSSTR done.\n","ɡ\n");
  WSGIappLocaleSet()->setLocaleString("EUCCN","C3:WSSTR Break","ж");
  WSGIappLocaleSet()->setLocaleString("EUCCN","D3:WSSTR Defaults,Environments,Imports,Compiling,Linking,Fonts,Etc..","Ĭֵ,,,,,,");
  WSGIappLocaleSet()->setLocaleString("EUCCN","E3:WSSTR Default colors","ָĬɫ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","F3:WSSTR Default size","ָĬϴС");
  WSGIappLocaleSet()->setLocaleString("EUCCN","G3:WSSTR Grid size","ָ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","H3:WSSTR :Horizontal",":");
  WSGIappLocaleSet()->setLocaleString("EUCCN","I3:WSSTR :Vertical",":");
  WSGIappLocaleSet()->setLocaleString("EUCCN","J3:WSSTR Base Window","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","K3:WSSTR Import Libraries","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","L3:WSSTR Add","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","M3:WSSTR Delete","ɾ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","N3:WSSTR Terminal","ֹ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","O3:WSSTR Source editor","ָ༭");
  WSGIappLocaleSet()->setLocaleString("EUCCN","O3:WSSTR Editor options","༭ѡ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","P3:WSSTR Web browser","Web");
  WSGIappLocaleSet()->setLocaleString("EUCCN","Q3:WSSTR Include path","ͨ Include ·");
  WSGIappLocaleSet()->setLocaleString("EUCCN","R3:WSSTR Compiler flags","ͨñѡ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","S3:WSSTR Compile mode","ģʽ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","T3:WSSTR  Debug mode"," ģʽ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","U3:WSSTR Application type","Application type");
  WSGIappLocaleSet()->setLocaleString("EUCCN","V3:WSSTR  Generate class library","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","W3:WSSTR Compiler","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","X3:WSSTR Runtime mode,Debug mode,Runtime static mode,Debug static mode","ͨģʽ,ģʽ,̬ͨģʽ,̬ģʽ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","Y3:WSSTR Include path","ض Include ·");
  WSGIappLocaleSet()->setLocaleString("EUCCN","Z3:WSSTR Compiler flags","ضѡ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","a3:WSSTR Include path"," Include ·");
  WSGIappLocaleSet()->setLocaleString("EUCCN","b3:WSSTR Compiler flags","ñѡ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","c3:WSSTR Libraries","ͨÿ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","d3:WSSTR Linker flags","ͨѡ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","e3:WSSTR Linker","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","f3:WSSTR Debugger","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","f3:WSSTR Make","Make");
  WSGIappLocaleSet()->setLocaleString("EUCCN","g3:WSSTR Runtime mode,Debug mode","ͨģʽ,ģʽ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","h3:WSSTR Libraries","ض");
  WSGIappLocaleSet()->setLocaleString("EUCCN","i3:WSSTR Output file","ļ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","j3:WSSTR Libraries","ÿ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","k3:WSSTR Output file","ļ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","l3:WSSTR Please select a target to delete.","ѡɾĿꡣ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","m3:WSSTR No-name","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","n3:WSSTR Name:WSN%s  Type:%s",":WSN%s  :%s");
  WSGIappLocaleSet()->setLocaleString("EUCCN","o3:WSSTR Invalid instance name.\nAlready used by another function name...","ָѱ̺ʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","p3:WSSTR Invalid instance name.\nAlready used by another instance name...","ָѱⲿʵʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","q3:WSSTR Invalid instance name.\nAlready used by another instance array name...","ָѱⲿʵʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","r3:WSSTR Invalid instance name.\nAlready used by project name or something...","ָѱʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","s3:WSSTR Can not use array name for application window.","޷ʹӦô顣");
  WSGIappLocaleSet()->setLocaleString("EUCCN","t3:WSSTR Can not use array name for class window.","޷ʹര顣");
  WSGIappLocaleSet()->setLocaleString("EUCCN","u3:WSSTR Invalid instance name.\nAlready used by another procedure name...","ָѱ̺ʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","v3:WSSTR Invalid instance name.\nAlready used by another external instance name...","ָѱⲿʵʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","w3:WSSTR Invalid instance array name.\nAlready used by another window, or invalid type.","ָѱʹãͲһ¡");
  WSGIappLocaleSet()->setLocaleString("EUCCN","x3:WSSTR Invalid instance name.\nAlready used by project name or something...","ָѱʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","y3:WSSTR Invalid instance name.","ָȷĶơ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","z3:WSSTR This trigger already exists.","ָĴѴڡ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","A3:WSSTR This trigger already exists.","ָĴѴڡ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","B3:WSSTR Can not delete the fixed trigger.","޷ɾָĴ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","C3:WSSTR Please select a trigger to delete.","ָɾĴ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","D3:WSSTR BaseClass","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","E3:WSSTR Base","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","F3:WSSTR If you change window definition type,\nyou have to change the type of the event procedure.\nDo you continue?","ͺ󣬱¼̵ȵĶ塣\n");
  WSGIappLocaleSet()->setLocaleString("EUCCN","G3:WSSTR If it makes the class definition window type into another type,\nit needs to change the type of the event procedure.\nDo you continue?","ඨ崰ͺ󣬱¼̵ȵĶ塣\n");
  WSGIappLocaleSet()->setLocaleString("EUCCN","H3:WSSTR inherit base instance: %s Not Found.\nPlease specify the correct instance name.","ָʵ: %s ڡ\nָȷʵ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","I3:WSSTR Invalid name.\nAlready used by another event procedure.","ָѱ̺ʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","J3:WSSTR Invalid name.\nAlready used by another instance name.","ָѱⲿʵʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","K3:WSSTR Invalid name.\nAlready used by another instance array name.","ָѱⲿʵʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","L3:WSSTR Invalid name.\nAlready used by the project name or the other one.","ָѱʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","M3:WSSTR Can not specify the array name for window.","޷ʹӦô顣");
  WSGIappLocaleSet()->setLocaleString("EUCCN","N3:WSSTR Can not specify the array name for class definition window.","޷ʹര顣");
  WSGIappLocaleSet()->setLocaleString("EUCCN","O3:WSSTR Invalid name.\nAlready used by another event procedure.","ָѱ̺ʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","P3:WSSTR Invalid name.\nAlready used by another external instance.","ָѱⲿʵʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","Q3:WSSTR Invalid array name.\nThe Array type differs from another one,or exists also another window.","ָѱʹãͲһ¡");
  WSGIappLocaleSet()->setLocaleString("EUCCN","R3:WSSTR Invalid name.\nAlready used by the project name or the other one.","ָѱʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","S3:WSSTR Invalid instance name.","ָȷĶơ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","T3:WSSTR ClassName","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","U3:WSSTR Normal window","ͨ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","V3:WSSTR Class definition","ര");
  WSGIappLocaleSet()->setLocaleString("EUCCN","W3:WSSTR Use object store","ʹö洢");
  WSGIappLocaleSet()->setLocaleString("EUCCN","X3:WSSTR Type","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","Y3:WSSTR Settings","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","Z3:WSSTR Properties","༭");
  WSGIappLocaleSet()->setLocaleString("EUCCN","a3:WSSTR Triggers","༭");
  WSGIappLocaleSet()->setLocaleString("EUCCN","b3:WSSTR UserTriggers","༭û");
  WSGIappLocaleSet()->setLocaleString("EUCCN","c3:WSSTR Icon","ͼ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","d3:WSSTR Comment","˵");
  WSGIappLocaleSet()->setLocaleString("EUCCN","e3:WSSTR Base","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","f3:WSSTR Name","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","g3:WSSTR File name","ļ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","h3:WSSTR Access","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","i3:WSSTR Global variable","ȫ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","j3:WSSTR Project","ע");
  WSGIappLocaleSet()->setLocaleString("EUCCN","k3:WSSTR Belong to this project","򹤳ע");
  WSGIappLocaleSet()->setLocaleString("EUCCN","l3:WSSTR Member","Ա");
  WSGIappLocaleSet()->setLocaleString("EUCCN","l3:WSSTR ENCODING","ϵ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","l3:WSSTR COMPAT","TARGET");
  WSGIappLocaleSet()->setLocaleString("EUCCN","l3:WSSTR Platform compatible","ƽ̨");
  WSGIappLocaleSet()->setLocaleString("EUCCN","l3:WSSTR Look & Feel","Look & Feel");
  WSGIappLocaleSet()->setLocaleString("EUCCN","l3:WSSTR Gradation","Gradation");
  WSGIappLocaleSet()->setLocaleString("EUCCN","l3:WSSTR Gui Policy","GUI");
  WSGIappLocaleSet()->setLocaleString("EUCCN","N3:WSSTR PropertyEditor","Ա༭");
  WSGIappLocaleSet()->setLocaleString("EUCCN","N3:WSSTR PropertyName:","ƣ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","N3:WSSTR PropertyType:","ͣ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","N3:WSSTR PropertyValue:","ֵ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","N3:WSSTR broken.","жϴ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","W3:WSSTR OBJS","Ӷ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","F3:WSSTR If you change class window name,\nyou have to reject your old source code\nand change the name of the event procedure.\nDo you continue?","󣬱ɵԴ¼̵ȵĶ塣\n");
  WSGIappLocaleSet()->setLocaleString("EUCCN","W3:WSSTR ColorBox","ɫ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","W3:WSSTR MessageBox","Ϣ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","j3:WSSTR RemoteClass","Զ̻");
  WSGIappLocaleSet()->setLocaleString("EUCCN","k3:WSSTR Generates the virtual remote class","Զ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","b3:WSSTR RemoteMethods","Զ̷");
  WSGIappLocaleSet()->setLocaleString("EUCCN","c3:WSSTR Return type,Method name","ֵ,");
  WSGIappLocaleSet()->setLocaleString("EUCCN","G3:WSSTR Parameters","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","c3:WSSTR Type,Name",",");
  WSGIappLocaleSet()->setLocaleString("EUCCN","W3:WSSTR Add","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","W3:WSSTR Del","ɾ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","W3:WSSTR Up","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","W3:WSSTR Down","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","E3:WSSTR Method name:","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","F3:WSSTR Return value type:","ֵ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","H3:WSSTR Name/Type","/");
  WSGIappLocaleSet()->setLocaleString("EUCCN","R3:WSSTR The method name is already used.","ָķѾʹá");
  WSGIappLocaleSet()->setLocaleString("EUCCN","S3:WSSTR Invalid method name.","Ƿķơ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","V3:WSSTR Please select the method.","ѡ񷽷");
  WSGIappLocaleSet()->setLocaleString("EUCCN","d3:WSSTR RemoteClassName:","Զ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","d3:WSSTR BaseClassName:","Զ̻");
  WSGIappLocaleSet()->setLocaleString("EUCCN","l3:WSSTR Language","");
  WSGIappLocaleSet()->setLocaleString("EUCCN","K3:WSSTR Edit...", "...");
  WSGIappLocaleSet()->setLocaleString("EUCCN","W3:WSSTR Name of the struct:","ṹ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","W3:WSSTR Name of the value:","ֵ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","W3:WSSTR Value:","ֵ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","c3:WSSTR Name,Value",",ֵ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","P3:WSSTR Ruby","Ruby");
  WSGIappLocaleSet()->setLocaleString("EUCCN","P3:WSSTR Ruby(DBG)","Ruby(DBG)");
  WSGIappLocaleSet()->setLocaleString("EUCCN","P3:WSSTR Python","Python");
  WSGIappLocaleSet()->setLocaleString("EUCCN","P3:WSSTR Python(DBG)","Python(DBG)");
  WSGIappLocaleSet()->setLocaleString("EUCCN","P3:WSSTR Perl","Perl");
  WSGIappLocaleSet()->setLocaleString("EUCCN","P3:WSSTR Perl(DBG)","Perl(DBG)");
  WSGIappLocaleSet()->setLocaleString("EUCCN","f3:WSSTR Static option","ӷʽ");
  WSGIappLocaleSet()->setLocaleString("EUCCN","l3:WSSTR Statically linked","̬");
  WSGIappLocaleSet()->setLocaleString("EUCCN","l3:WSSTR Dynamically linked","̬");

